@@ -301,7 +301,7 @@ var Search = {
   },
 
   query : function(query) {
-    var stopwords = ["near","by","as","of","is","are","this","but","in","into","with","the","a","then","it","if","at","their","be","will","or","for","to","that","these","such","and","was","not","there","on","they","no"];
+    var stopwords = ["but","no","be","for","their","these","into","that","not","are","and","by","of","near","if","they","on","a","or","in","will","this","was","is","it","then","the","such","with","as","at","there","to"];
 
     // Stem the searchterms and add them to the correct list
     var stemmer = new Stemmer();
